@@ -20,8 +20,10 @@
 #' @export mfl_connect
 #'
 #' @examples
+#' \donttest{
 #' mfl_connect(season = 2020, league_id = 54040)
 #' mfl_connect(season = 2019, league_id = 54040, rate_limit = FALSE)
+#' }
 #' @return a connection object to be used with \code{ff_*} functions
 #' @seealso \code{\link{ff_connect}}, \code{\link{sleeper_connect}}
 
@@ -57,7 +59,7 @@ mfl_connect <- function(season = NULL,
   if (!rate_limit ||
     (!is.null(rate_limit_number) & !is.null(rate_limit_number))
   ) {
-    .fn_set_ratelimit(rate_limit, "MFL", rate_limit_number, rate_limit_seconds)
+    .fn_set_ratelimit(rate_limit, "mfl", rate_limit_number, rate_limit_seconds)
   }
 
   ## SEASON ##
