@@ -1,5 +1,6 @@
 with_mock_api({
   test_that("ff_playerscores returns a tibble of player scores", {
+    skippy()
     sfb_conn <- mfl_connect(2020, 65443)
 
     sfb_playerscores <- ff_playerscores(sfb_conn, 2019, "AVG")
@@ -13,5 +14,10 @@ with_mock_api({
     joe_playerscores <- ff_playerscores(joe_conn, page_limit = 2)
 
     expect_tibble(joe_playerscores, min.rows = 50)
+
+    tony_conn <- espn_connect(season = 2020, league_id = 899513)
+    tony_playerscores <- ff_playerscores(tony_conn, limit = 5)
+
+    expect_tibble(tony_playerscores, min.rows = 5)
   })
 })
