@@ -1,5 +1,7 @@
 with_mock_api({
-  test_that("ff_transactions returns a tibble of starters", {
+  test_that("ff_starters returns a tibble of starters", {
+    skippy()
+
     dlf <- mfl_connect(2020, 37920)
     dlf_starters <- ff_starters(dlf, week = c(1:3), year = 2020)
 
@@ -14,5 +16,12 @@ with_mock_api({
     got_starters <- ff_starters(got_conn, week = 4)
 
     expect_tibble(got_starters, min.rows = 100)
+
+    tony_conn <- espn_connect(season = 2020, league_id = 899513)
+    tony_starters <- ff_starters(tony_conn, weeks = 1:2)
+    tony_potentialpoints <- espn_potentialpoints(tony_conn, weeks = 1:2)
+
+    expect_tibble(tony_starters, min.rows = 100)
+    expect_tibble(tony_potentialpoints, min.rows = 100)
   })
 })
